function [ tv, uv ] = backward_euler( fun, dfun, y0, t0, tf, Nh )
% BACKWARD_EULER Backward Euler method for the scalar ODE in the form
% y'(t) = f(t,y(t)),  t \in (t0,tf)
% y(0) = y_0
%
%  [ tv, uv ] = backward_euler( fun, dfun, y0, t0, tf, h )
%  Inputs: fun    = function handle for f(t,y), fun = @(t,y) ...
%          dfun   = function handle for df(t,y), dfun = @(t,y) ...
%          y0     = initial value
%          t0     = initial time
%          tf     = final time
%          Nh     = number of subintervals
%  Output: tv     = vector of time steps (1 x (Nh+1))
%          uv     = vector of approximate solution at times tv
%

return
